==> GenomeARTIST_v1.17b_src.zip: src/exenne/components/treetable/RowModel.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanid this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

/*
 * RowModel.java
 *
 * Created on January 28, 2004, 11:07 PM
 */

package exenne.components.treetable;

import java.awt.Color;
import javax.swing.CellEditor;
import javax.swing.table.TableCellRenderer;

/** A model for the rows in an Outline.  This is passed the object in
 * column 0 of an Outline table (the tree column), and provides objects
 * for the other columns - essentially a model for the data in the
 * rows of an Outline.
 * <p>
 * Note that all column indexes passed to this interface are 0-based -
 * that is, column 0 is the first column <strong>after</strong> the
 * tree node column, so the object returned by <code>getValueFor(someObject, 0)</code>
 * is the object that should appear in column <strong>1</strong> of the
 * actual table.
 * <p>
 *
 * @author Tim Boudreau
 */
public interface RowModel {
    
     /** Get the object class for the column.  Analogous to
     * <code>TableModel.getColumnClass(int column)</code>
     * @param column an index into the columns represented by this model (0
     *  based - does not include the tree column of the OutlineModel)
     * @return the class of object that will be displayed in the specified
     * column */
    public Class getColumnClass(int column);   
    
    /** Get the column count.  Do not include the base (nodes) column
     * of the Outline, only the number of columns in addition to it
     * that should be displayed.
     * @return the number of columns this model will contribute to the
     *  OutlineModel, not including the tree column */
    public int getColumnCount();

    /** Get a localized name of this column that can be displayed in
     * the table header
     * @param column the column a name is requested for
     * @return a localized name for the column  */
    public String getColumnName(int column);

    /**
     * Obtin dimensiunea preferata pentru o coloana
     * @param column
     * @return 
     */
    public int getColumnPrefferedWidth(int column);
    
    /**
     * Obtin re
     * @param column
     * @return 
     */
    public TableCellRenderer getColumnHeaderRenderer(int column);
    
    /**
     * Obtin editorul pentru o anumita coloana
     * @param column
     * @return 
     */
    public CellEditor getColumnCellEditor(int column);
    
    
    /** Get the value at a given column.
     * @param node The node in column 0 of the Outline
     * @param column The index of the column minus the nodes column
     * @return the value that should be displayed in the specified column,
     *  given the node in the tree column */
    public Object getValueFor(Object node, int column);

    /** Get the value at a given column.
     * @param node The node in column 0 of the Outline
     * @param column The index of the column minus the nodes column
     * @return the value that should be displayed in the specified column,
     *  given the node in the tree column */
    public String getTooltipTextFor(Object node, int column);

    /** Determine if the cell in this column is editable for the passed
     * node.
     * @param node the object displayed in the tree column of the Outline
     * @param column the column index into the columns defined by this
     *  RowModel  */
    public boolean isCellEditable(Object node, int column);

    /**
     * Set the value of the object in this column.  Typically this may
     * call a setter on the node object in column 0
     * @param node The tree node wich is being modified
     * @param column Modified column
     * @param value The new value
     * @return true - if setting the value was possible, false otherwise
     *       returning false will make the treetable not to launch a
     *       table update event
     */
    public boolean setValueFor(Object node, int column, Object value);    
    
    /**
     * Specify if this cell is important and must be rendered special
     * @param node
     * @param column
     * @return
     */
    public boolean isCellImportant(Object node, boolean isExpanded, int column );

    /**
     * If one wants to alter the value that is represented should
     * return a non null value
     * @param node
     * @param column
     * @return
     */
    public String getOverwriteString(Object node, boolean isExpanded, int column);

    /**
     * If the cell wants to overwrite the row background
     * return a non null value
     * @param node
     * @param column
     * @return
     */
    public Color getOverwriteBackground(Object node, boolean isExpanded, int column);

    /**
     * If the cell wants to overwrite the row foreground
     * return a non null value
     * @param node
     * @param column
     * @return
     */
    public Color getOverwriteForeground(Object node, boolean isExpanded, int column);
}

==> GenomeARTIST_v1.19_src.zip: src/exenne/components/treetable/RowModel.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanid this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Contributor(s):
 *
 * The Original Software is NetBeans. The Initial Developer of the Original
 * Software is Sun Microsystems, Inc. Portions Copyright 1997-2007 Sun
 * Microsystems, Inc. All Rights Reserved.
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 */

/*
 * RowModel.java
 *
 * Created on January 28, 2004, 11:07 PM
 */

package exenne.components.treetable;

import java.awt.Color;
import javax.swing.table.TableCellEditor;
import javax.swing.table.TableCellRenderer;

/** A model for the rows in an Outline.  This is passed the object in
 * column 0 of an Outline table (the tree column), and provides objects
 * for the other columns - essentially a model for the data in the
 * rows of an Outline.
 * <p>
 * Note that all column indexes passed to this interface are 0-based -
 * that is, column 0 is the first column <strong>after</strong> the
 * tree node column, so the object returned by <code>getValueFor(someObject, 0)</code>
 * is the object that should appear in column <strong>1</strong> of the
 * actual table.
 * <p>
 *
 * @author Tim Boudreau
 */
public interface RowModel {
    
     /** Get the object class for the column.  Analogous to
     * <code>TableModel.getColumnClass(int column)</code>
     * @param column an index into the columns represented by this model (0
     *  based - does not include the tree column of the OutlineModel)
     * @return the class of object that will be displayed in the specified
     * column */
    public Class getColumnClass(int column);   
    
    /** Get the column count.  Do not include the base (nodes) column
     * of the Outline, only the number of columns in addition to it
     * that should be displayed.
     * @return the number of columns this model will contribute to the
     *  OutlineModel, not including the tree column */
    public int getColumnCount();

    /** Get a localized name of this column that can be displayed in
     * the table header
     * @param column the column a name is requested for
     * @return a localized name for the column  */
    public String getColumnName(int column);

    /**
     * Obtin dimensiunea preferata pentru o coloana
     * @param column
     * @return 
     */
    public int getColumnPrefferedWidth(int column);
    
    /**
     * Obtin re
     * @param column
     * @return 
     */
    public TableCellRenderer getColumnHeaderRenderer(int column);
    
    /**
     * Obtin editorul pentru o anumita coloana
     * @param column
     * @return 
     */
    public TableCellEditor getColumnCellEditor(int column);
    
    
    /** Get the value at a given column.
     * @param node The node in column 0 of the Outline
     * @param column The index of the column minus the nodes column
     * @return the value that should be displayed in the specified column,
     *  given the node in the tree column */
    public Object getValueFor(Object node, int column);

    /** Get the value at a given column.
     * @param node The node in column 0 of the Outline
     * @param column The index of the column minus the nodes column
     * @return the value that should be displayed in the specified column,
     *  given the node in the tree column */
    public String getTooltipTextFor(Object node, int column);

    /** Determine if the cell in this column is editable for the passed
     * node.
     * @param node the object displayed in the tree column of the Outline
     * @param column the column index into the columns defined by this
     *  RowModel  */
    public boolean isCellEditable(Object node, int column);

    /**
     * Set the value of the object in this column.  Typically this may
     * call a setter on the node object in column 0
     * @param node The tree node wich is being modified
     * @param column Modified column
     * @param value The new value
     * @return true - if setting the value was possible, false otherwise
     *       returning false will make the treetable not to launch a
     *       table update event
     */
    public boolean setValueFor(Object node, int column, Object value);    
    
    /**
     * Specify if this cell is important and must be rendered special
     * @param node
     * @param column
     * @return
     */
    public boolean isCellImportant(Object node, boolean isExpanded, int column );

    /**
     * If one wants to alter the value that is represented should
     * return a non null value
     * @param node
     * @param column
     * @return
     */
    public String getOverwriteString(Object node, boolean isExpanded, int column);

    /**
     * If the cell wants to overwrite the row background
     * return a non null value
     * @param node
     * @param column
     * @return
     */
    public Color getOverwriteBackground(Object node, boolean isExpanded, int column);

    /**
     * If the cell wants to overwrite the row foreground
     * return a non null value
     * @param node
     * @param column
     * @return
     */
    public Color getOverwriteForeground(Object node, boolean isExpanded, int column);
}
